@@ -10,8 +10,7 @@ from .asset import asset_cli
 from .debug import debug_cli
 from .instance import instance_cli
 from .job import job_cli
-from .new_project import new_project_cli
-from .pipeline import pipeline_cli
+from .project import project_cli
 from .run import run_cli
 from .schedule import schedule_cli
 from .sensor import sensor_cli
@@ -20,7 +19,6 @@ from .sensor import sensor_cli
 def create_dagster_cli():
     commands = {
         "api": api_cli,
-        "pipeline": pipeline_cli,
         "job": job_cli,
         "run": run_cli,
         "instance": instance_cli,
@@ -28,7 +26,7 @@ def create_dagster_cli():
         "sensor": sensor_cli,
         "asset": asset_cli,
         "debug": debug_cli,
-        "new-project": new_project_cli,
+        "project": project_cli,
     }
 
     @click.group(
