@@ -4,27 +4,39 @@ from typing import Sequence
 
 import click
 
-from dagster._generate import download_example_from_github, generate_project, generate_repository
+from dagster._generate import (
+    download_example_from_github,
+    generate_code_location,
+    generate_project,
+    generate_repository,
+)
 from dagster._generate.download import AVAILABLE_EXAMPLES
 
 
 @click.group(name="project")
 def project_cli():
     """
-    Commands for bootstrapping new Dagster projects and repositories.
+    Commands for bootstrapping new Dagster projects and code locations.
     """
 
 
 scaffold_repository_command_help_text = (
+    "(DEPRECATED; Use `dagster project scaffold-code-location` instead) "
     "Create a folder structure with a single Dagster repository, in the current directory. "
     "This CLI helps you to scaffold a new Dagster repository within a folder structure that "
     "includes multiple Dagster repositories"
 )
 
+scaffold_code_location_command_help_text = (
+    "Create a folder structure with a single Dagster code location, in the current directory. "
+    "This CLI helps you to scaffold a new Dagster code location within a folder structure that "
+    "includes multiple Dagster code locations."
+)
+
 scaffold_command_help_text = (
-    "Create a folder structure with a single Dagster repository and other files such as "
-    "workspace.yaml, in the target directory set by the --name option. This CLI enables "
-    "you to quickly start building a new Dagster project with everything set up."
+    "Create a folder structure with a single Dagster code location and other files such as "
+    "pyproject.toml. This CLI enables you to quickly start building a new Dagster project with "
+    "everything set up."
 )
 
 from_example_command_help_text = (
@@ -55,10 +67,40 @@ def scaffold_repository_command(name: str):
         )
         sys.exit(1)
 
+    click.echo(
+        click.style(
+            "WARNING: This command is deprecated. Use `dagster project scaffold-code-location` instead.",
+            fg="yellow",
+        )
+    )
     generate_repository(dir_abspath)
     click.echo(_styled_success_statement(name, dir_abspath))
 
 
+@project_cli.command(
+    name="scaffold-code-location",
+    short_help=scaffold_code_location_command_help_text,
+    help=scaffold_code_location_command_help_text,
+)
+@click.option(
+    "--name",
+    required=True,
+    type=click.STRING,
+    help="Name of the new Dagster code location",
+)
+def scaffold_code_location_command(name: str):
+    dir_abspath = os.path.abspath(name)
+    if os.path.isdir(dir_abspath) and os.path.exists(dir_abspath):
+        click.echo(
+            click.style(f"The directory {dir_abspath} already exists. ", fg="red")
+            + "\nPlease delete the contents of this path or choose another location."
+        )
+        sys.exit(1)
+
+    generate_code_location(dir_abspath)
+    click.echo(_styled_success_statement(name, dir_abspath))
+
+
 @project_cli.command(
     name="scaffold",
     short_help=scaffold_command_help_text,
