@@ -1,15 +1,12 @@
 import inspect
-import warnings
-from collections import defaultdict
 from importlib import import_module
 from types import ModuleType
 from typing import (
     TYPE_CHECKING,
+    AbstractSet,
     Any,
-    Dict,
     FrozenSet,
     Iterable,
-    List,
     Mapping,
     Optional,
     Sequence,
@@ -20,39 +17,30 @@ from typing import (
 import dagster._check as check
 from dagster._core.definitions.dependency import NodeHandle
 from dagster._core.definitions.events import AssetKey, CoercibleToAssetKeyPrefix
-from dagster._core.definitions.executor_definition import in_process_executor
+from dagster._core.definitions.executor_definition import ExecutorDefinition, in_process_executor
 from dagster._core.definitions.utils import DEFAULT_IO_MANAGER_KEY
 from dagster._core.errors import (
     DagsterInvalidDefinitionError,
     DagsterUnmetExecutorRequirementsError,
 )
 from dagster._core.selector.subset_selector import AssetSelectionData
-from dagster._core.storage.fs_io_manager import fs_io_manager
 from dagster._utils import merge_dicts
-from dagster._utils.backcompat import ExperimentalWarning
 
 from .asset_layer import build_asset_selection_job
 from .assets import AssetsDefinition
-from .assets_job import build_assets_job, check_resources_satisfy_requirements
-from .dependency import NodeHandle
-from .events import AssetKey, CoercibleToAssetKeyPrefix
-from .executor_definition import ExecutorDefinition, in_process_executor
-from .job_definition import JobDefinition
+from .assets_job import check_resources_satisfy_requirements
+from .job_definition import JobDefinition, default_job_io_manager_with_fs_io_manager_schema
 from .load_assets_from_modules import (
     assets_and_source_assets_from_modules,
     assets_and_source_assets_from_package_module,
     prefix_assets,
 )
-from .partition import PartitionsDefinition
 from .resource_definition import ResourceDefinition
 from .source_asset import SourceAsset
 
 if TYPE_CHECKING:
     from dagster._core.execution.execute_in_process_result import ExecuteInProcessResult
 
-# Prefix for auto created jobs that are used to materialize assets
-ASSET_BASE_JOB_PREFIX = "__ASSET_JOB"
-
 
 class AssetGroup:
     """Defines a group of assets, along with environment information in the
@@ -124,7 +112,10 @@ class AssetGroup:
         resource_defs = check.opt_mapping_param(
             resource_defs, "resource_defs", key_type=str, value_type=ResourceDefinition
         )
-        resource_defs = merge_dicts({DEFAULT_IO_MANAGER_KEY: fs_io_manager}, resource_defs)
+        resource_defs = merge_dicts(
+            {DEFAULT_IO_MANAGER_KEY: default_job_io_manager_with_fs_io_manager_schema},
+            resource_defs,
+        )
         executor_def = check.opt_inst_param(executor_def, "executor_def", ExecutorDefinition)
 
         check_resources_satisfy_requirements(assets, source_assets, resource_defs)
@@ -150,16 +141,12 @@ class AssetGroup:
     def executor_def(self):
         return self._executor_def
 
-    @staticmethod
-    def is_base_job_name(name) -> bool:
-        return name.startswith(ASSET_BASE_JOB_PREFIX)
-
     def build_job(
         self,
         name: str,
-        selection: Optional[Union[str, List[str]]] = None,
+        selection: Optional[Union[str, Sequence[str]]] = None,
         executor_def: Optional[ExecutorDefinition] = None,
-        tags: Optional[Dict[str, Any]] = None,
+        tags: Optional[Mapping[str, Any]] = None,
         description: Optional[str] = None,
         _asset_selection_data: Optional[AssetSelectionData] = None,
     ) -> JobDefinition:
@@ -205,7 +192,7 @@ class AssetGroup:
         check.str_param(name, "name")
         check.opt_inst_param(_asset_selection_data, "_asset_selection_data", AssetSelectionData)
 
-        selected_asset_keys: FrozenSet[AssetKey] = frozenset()
+        selected_asset_keys: AbstractSet[AssetKey] = frozenset()
         if isinstance(selection, str):
             selected_asset_keys = parse_asset_selection(
                 self.assets, self.source_assets, [selection]
@@ -221,7 +208,7 @@ class AssetGroup:
             executor_def, "executor_def", ExecutorDefinition, self.executor_def
         )
         description = check.opt_str_param(description, "description", "")
-        tags = check.opt_dict_param(tags, "tags", key_type=str)
+        tags = check.opt_mapping_param(tags, "tags", key_type=str)
 
         return build_asset_selection_job(
             name=name,
@@ -372,7 +359,9 @@ class AssetGroup:
         )
 
     def materialize(
-        self, selection: Optional[Union[str, List[str]]] = None, run_config: Optional[Any] = None
+        self,
+        selection: Optional[Union[str, Sequence[str]]] = None,
+        run_config: Optional[Any] = None,
     ) -> "ExecuteInProcessResult":
         """
         Executes an in-process run that materializes all assets in the group.
@@ -404,42 +393,6 @@ class AssetGroup:
             name="in_process_materialization_job", selection=selection
         ).execute_in_process(run_config=run_config)
 
-    def get_base_jobs(self) -> Sequence[JobDefinition]:
-        """For internal use only."""
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore", category=ExperimentalWarning)
-
-            assets_by_partitions_def: Dict[
-                Optional[PartitionsDefinition], List[AssetsDefinition]
-            ] = defaultdict(list)
-            for assets_def in self.assets:
-                assets_by_partitions_def[assets_def.partitions_def].append(assets_def)
-
-            if len(assets_by_partitions_def.keys()) == 0 or assets_by_partitions_def.keys() == {
-                None
-            }:
-                return [self.build_job(ASSET_BASE_JOB_PREFIX)]
-            else:
-                unpartitioned_assets = assets_by_partitions_def.get(None, [])
-                jobs = []
-
-                # sort to ensure some stability in the ordering
-                for i, (partitions_def, assets_with_partitions) in enumerate(
-                    sorted(assets_by_partitions_def.items(), key=lambda item: repr(item[0]))
-                ):
-                    if partitions_def is not None:
-                        jobs.append(
-                            build_assets_job(
-                                f"{ASSET_BASE_JOB_PREFIX}_{i}",
-                                assets=assets_with_partitions + unpartitioned_assets,
-                                source_assets=[*self.source_assets, *self.assets],
-                                resource_defs=self.resource_defs,
-                                executor_def=self.executor_def,
-                            )
-                        )
-
-                return jobs
-
     def prefixed(self, key_prefix: CoercibleToAssetKeyPrefix):
         """
         Returns an AssetGroup that's identical to this AssetGroup, but with prefixes on all the
