@@ -21,13 +21,12 @@ from typing import (
 import dagster._check as check
 from dagster._core.definitions.events import AssetKey
 from dagster._core.definitions.metadata import MetadataUserInput, RawMetadataValue
-from dagster._core.definitions.op_definition import OpDefinition
 from dagster._core.selector.subset_selector import AssetSelectionData
 from dagster._utils.backcompat import ExperimentalWarning
 
 from ..errors import DagsterInvalidSubsetError
 from .config import ConfigMapping
-from .dependency import NodeHandle, NodeInputHandle, NodeOutputHandle, SolidOutputHandle
+from .dependency import NodeHandle, NodeInputHandle, NodeOutput, NodeOutputHandle
 from .events import AssetKey
 from .executor_definition import ExecutorDefinition
 from .graph_definition import GraphDefinition
@@ -37,6 +36,7 @@ from .resource_definition import ResourceDefinition
 if TYPE_CHECKING:
     from dagster._core.definitions.assets import AssetsDefinition, SourceAsset
     from dagster._core.definitions.job_definition import JobDefinition
+    from dagster._core.definitions.partition_mapping import PartitionMapping
     from dagster._core.definitions.resolved_asset_defs import ResolvedAssetDependencies
     from dagster._core.execution.context.output import OutputContext
 
@@ -51,6 +51,7 @@ class AssetOutputInfo(
             ("partitions_fn", Callable[["OutputContext"], Optional[AbstractSet[str]]]),
             ("partitions_def", Optional["PartitionsDefinition"]),
             ("is_required", bool),
+            ("code_version", Optional[str]),
         ],
     )
 ):
@@ -63,6 +64,7 @@ class AssetOutputInfo(
             for this asset.
         partitions_def (PartitionsDefinition, optional): Defines the set of valid partitions
             for this asset.
+        code_version (Optional[str], optional): The version of the code that generates this asset.
     """
 
     def __new__(
@@ -71,6 +73,7 @@ class AssetOutputInfo(
         partitions_fn: Optional[Callable[["OutputContext"], Optional[AbstractSet[str]]]] = None,
         partitions_def: Optional["PartitionsDefinition"] = None,
         is_required: bool = True,
+        code_version: Optional[str] = None,
     ):
         return super().__new__(
             cls,
@@ -78,6 +81,7 @@ class AssetOutputInfo(
             partitions_fn=check.opt_callable_param(partitions_fn, "partitions_fn", lambda _: None),
             partitions_def=partitions_def,
             is_required=is_required,
+            code_version=code_version,
         )
 
 
@@ -104,11 +108,13 @@ def _resolve_input_to_destinations(
     return all_destinations
 
 
-def _resolve_output_to_destinations(output_name, node_def, handle) -> Sequence[NodeInputHandle]:
-    node_input_handles: List[NodeInputHandle] = []
+def _resolve_output_to_destinations(
+    output_name: str, node_def: NodeDefinition, handle: NodeHandle
+) -> Sequence[NodeInputHandle]:
+    all_destinations: List[NodeInputHandle] = []
     if not isinstance(node_def, GraphDefinition):
         # must be in the op definition
-        return node_input_handles
+        return all_destinations
 
     for mapping in node_def.output_mappings:
         if mapping.graph_output_name != output_name:
@@ -116,7 +122,7 @@ def _resolve_output_to_destinations(output_name, node_def, handle) -> Sequence[N
         output_pointer = mapping.maps_from
         output_node = node_def.solid_named(output_pointer.solid_name)
 
-        node_input_handles.extend(
+        all_destinations.extend(
             _resolve_output_to_destinations(
                 output_pointer.output_name,
                 output_node.definition,
@@ -126,27 +132,27 @@ def _resolve_output_to_destinations(output_name, node_def, handle) -> Sequence[N
 
         output_def = output_node.definition.output_def_named(output_pointer.output_name)
         downstream_input_handles = (
-            node_def.dependency_structure.output_to_downstream_inputs_for_solid(
+            node_def.dependency_structure.output_to_downstream_inputs_for_node(
                 output_pointer.solid_name
-            ).get(SolidOutputHandle(output_node, output_def), [])
+            ).get(NodeOutput(output_node, output_def), [])
         )
         for input_handle in downstream_input_handles:
-            node_input_handles.append(
+            all_destinations.append(
                 NodeInputHandle(
                     NodeHandle(input_handle.solid_name, parent=handle), input_handle.input_name
                 )
             )
 
-    return node_input_handles
+    return all_destinations
 
 
 def _build_graph_dependencies(
     graph_def: GraphDefinition,
-    parent_handle: Union[NodeHandle, None],
+    parent_handle: Optional[NodeHandle],
     outputs_by_graph_handle: Dict[NodeHandle, Mapping[str, NodeOutputHandle]],
     non_asset_inputs_by_node_handle: Dict[NodeHandle, Sequence[NodeOutputHandle]],
     assets_defs_by_node_handle: Mapping[NodeHandle, "AssetsDefinition"],
-):
+) -> None:
     """
     Scans through every node in the graph, making a recursive call when a node is a graph.
 
@@ -179,11 +185,11 @@ def _build_graph_dependencies(
             }
         non_asset_inputs_by_node_handle[curr_node_handle] = [
             NodeOutputHandle(
-                NodeHandle(output_handle.solid_name, parent=parent_handle),
-                output_handle.output_def.name,
+                NodeHandle(node_output.node_name, parent=parent_handle),
+                node_output.output_def.name,
             )
-            for output_handle in dep_struct.all_upstream_outputs_from_solid(sub_node_name)
-            if NodeHandle(output_handle.solid.name, parent=parent_handle)
+            for node_output in dep_struct.all_upstream_outputs_from_node(sub_node_name)
+            if NodeHandle(node_output.node.name, parent=parent_handle)
             not in assets_defs_by_node_handle
         ]
 
@@ -256,7 +262,7 @@ def _get_dependency_node_output_handles(
 
 def get_dep_node_handles_of_graph_backed_asset(
     graph_def: GraphDefinition, assets_def: "AssetsDefinition"
-):
+) -> Mapping[AssetKey, Set[NodeHandle]]:
     """
     Given a graph-backed asset with graph_def, return a mapping of asset keys outputted by the graph
     to a list of node handles within graph_def that are the dependencies of the asset.
@@ -421,6 +427,7 @@ def _asset_mappings_for_node(
                     key=output_key,
                     partitions_fn=output_def.get_asset_partitions,
                     partitions_def=output_def.asset_partitions_def,
+                    code_version=output_def.code_version,
                 )
                 # assume output depends on all inputs
                 asset_deps[output_key] = input_asset_keys
@@ -493,7 +500,7 @@ class AssetLayer:
             key_type=NodeInputHandle,
             value_type=AssetKey,
         )
-        self._asset_info_by_node_output_handle = check.opt_dict_param(
+        self._asset_info_by_node_output_handle = check.opt_mapping_param(
             asset_info_by_node_output_handle,
             "asset_info_by_node_output_handle",
             key_type=NodeOutputHandle,
@@ -535,7 +542,7 @@ class AssetLayer:
 
         # Used to store the asset key dependencies of op node handles within graph backed assets
         # See AssetLayer.downstream_dep_assets for more information
-        self._node_output_handle_to_dep_asset_keys = check.opt_dict_param(
+        self._node_output_handle_to_dep_asset_keys = check.opt_mapping_param(
             node_output_handles_to_dep_asset_keys,
             "node_output_handles_to_dep_asset_keys",
             key_type=NodeOutputHandle,
@@ -633,6 +640,7 @@ class AssetLayer:
                     partitions_fn=partitions_fn if assets_def.partitions_def else None,
                     partitions_def=assets_def.partitions_def,
                     is_required=asset_key in assets_def.keys,
+                    code_version=inner_output_def.code_version,
                 )
                 io_manager_by_asset[asset_key] = inner_output_def.io_manager_key
 
@@ -721,10 +729,10 @@ class AssetLayer:
         assets_def = self.assets_defs_by_key.get(asset_key)
         return False if assets_def is None else isinstance(assets_def.node_def, GraphDefinition)
 
-    def op_version_for_asset(self, asset_key: AssetKey) -> Optional[str]:
+    def code_version_for_asset(self, asset_key: AssetKey) -> Optional[str]:
         assets_def = self.assets_defs_by_key.get(asset_key)
-        if assets_def is not None and isinstance(assets_def.node_def, OpDefinition):
-            return assets_def.node_def.version
+        if assets_def is not None:
+            return assets_def.code_versions_by_key[asset_key]
         else:
             return None
 
@@ -776,6 +784,14 @@ class AssetLayer:
 
         return None
 
+    def partition_mapping_for_asset_dep(
+        self, asset_key: AssetKey, upstream_asset_key: AssetKey
+    ) -> Optional["PartitionMapping"]:
+        assets_def = self._assets_defs_by_key.get(asset_key)
+        if not assets_def:
+            return None
+        return assets_def.get_partition_mapping(upstream_asset_key)
+
     def downstream_dep_assets(self, node_handle: NodeHandle, output_name: str) -> Set[AssetKey]:
         """
         Given the node handle of an op within a graph-backed asset and an output name,
