@@ -34,6 +34,7 @@ from .partition import PartitionsDefinition, PartitionsSubset
 from .repository_definition import RepositoryDefinition
 from .run_request import RunRequest
 from .sensor_definition import DefaultSensorStatus, SensorDefinition
+from .time_window_partitions import TimeWindowPartitionsDefinition
 from .utils import check_valid_name
 
 if TYPE_CHECKING:
@@ -85,7 +86,7 @@ class AssetReconciliationCursor(NamedTuple):
 
         for run_request in run_requests:
             for asset_key in cast(Iterable[AssetKey], run_request.asset_selection):
-                if len(asset_graph.get_parents(asset_key)) == 0:
+                if not asset_graph.has_non_source_parents(asset_key):
                     if run_request.partition_key:
                         requested_root_partitions_by_asset_key[asset_key].add(
                             run_request.partition_key
@@ -188,36 +189,56 @@ class ToposortedPriorityQueue:
     @functools.total_ordering
     class QueueItem(NamedTuple):
         level: int
+        partition_sort_key: Optional[float]
         asset_partition: AssetKeyPartitionKey
 
         def __eq__(self, other):
-            return self.level == other.level
+            return self.level == other.level and self.partition_sort_key == other.partition_sort_key
 
         def __lt__(self, other):
-            return self.level < other.level
+            return self.level < other.level or (
+                self.level == other.level
+                and self.partition_sort_key is not None
+                and self.partition_sort_key < other.partition_sort_key
+            )
 
     def __init__(self, asset_graph: AssetGraph, items: Iterable[AssetKeyPartitionKey]):
+        self._asset_graph = asset_graph
         toposorted_asset_keys = asset_graph.toposort_asset_keys()
         self._toposort_level_by_asset_key = {
             asset_key: i
             for i, asset_keys in enumerate(toposorted_asset_keys)
             for asset_key in asset_keys
         }
-        self._heap = [
-            ToposortedPriorityQueue.QueueItem(
-                self._toposort_level_by_asset_key[asset_partition.asset_key], asset_partition
-            )
-            for asset_partition in items
-        ]
+        self._heap = [self._queue_item(asset_partition) for asset_partition in items]
         heapify(self._heap)
 
     def enqueue(self, asset_partition: AssetKeyPartitionKey) -> None:
-        priority = self._toposort_level_by_asset_key[asset_partition.asset_key]
-        heappush(self._heap, ToposortedPriorityQueue.QueueItem(priority, asset_partition))
+        heappush(self._heap, self._queue_item(asset_partition))
 
     def dequeue(self) -> AssetKeyPartitionKey:
         return heappop(self._heap).asset_partition
 
+    def _queue_item(self, asset_partition: AssetKeyPartitionKey):
+        asset_key = asset_partition.asset_key
+        level = self._toposort_level_by_asset_key[asset_key]
+        if self._asset_graph.has_self_dependency(asset_key):
+            partitions_def = self._asset_graph.get_partitions_def(asset_key)
+            if partitions_def is not None and isinstance(
+                partitions_def, TimeWindowPartitionsDefinition
+            ):
+                partition_sort_key = (
+                    cast(TimeWindowPartitionsDefinition, partitions_def)
+                    .time_window_for_partition_key(cast(str, asset_partition.partition_key))
+                    .start.timestamp()
+                )
+            else:
+                check.failed("Assets with self-dependencies must have time-window partitions")
+        else:
+            partition_sort_key = None
+
+        return ToposortedPriorityQueue.QueueItem(level, partition_sort_key, asset_partition)
+
     def __len__(self) -> int:
         return len(self._heap)
 
@@ -254,9 +275,8 @@ def find_stale_candidates(
     ).items():
         # The children of updated assets might now be unreconciled:
         for child in asset_graph.get_children_partitions(asset_key, record.partition_key):
-            if (
-                child.asset_key in target_asset_keys
-                and not instance_queryer.is_asset_partition_in_run(record.run_id, child)
+            if child.asset_key in target_asset_keys and not instance_queryer.is_asset_in_run(
+                record.run_id, child
             ):
                 stale_candidates.add(child)
 
@@ -342,6 +362,7 @@ def determine_asset_partitions_to_reconcile(
         target_asset_selection=target_asset_selection,
         asset_graph=asset_graph,
     )
+
     target_asset_keys = target_asset_selection.resolve(asset_graph)
 
     to_reconcile: Set[AssetKeyPartitionKey] = set()
@@ -369,6 +390,7 @@ def determine_asset_partitions_to_reconcile(
                         and asset_graph.have_same_partitioning(
                             parent.asset_key, candidate.asset_key
                         )
+                        and parent.partition_key == candidate.partition_key
                     )
                     or (
                         instance_queryer.is_reconciled(
@@ -385,6 +407,10 @@ def determine_asset_partitions_to_reconcile(
             )
         ):
             to_reconcile.add(candidate)
+            # add in all of the neighbor keys which must be materialized alongside this one
+            for required_key in asset_graph.get_required_multi_asset_keys(candidate.asset_key):
+                to_reconcile.add(AssetKeyPartitionKey(required_key, candidate.partition_key))
+
             for child in asset_graph.get_children_partitions(
                 candidate.asset_key, candidate.partition_key
             ):
@@ -509,43 +535,33 @@ def get_expected_data_times_for_key(
 
 
 def get_execution_time_window_for_constraints(
-    instance_queryer: CachingInstanceQueryer,
     constraints: AbstractSet[FreshnessConstraint],
-    current_time: datetime.datetime,
     current_data_times: Mapping[AssetKey, Optional[datetime.datetime]],
+    in_progress_data_times: Mapping[AssetKey, Optional[datetime.datetime]],
     expected_data_times: Mapping[AssetKey, Optional[datetime.datetime]],
-    asset_key: AssetKey,
 ) -> Tuple[Optional[datetime.datetime], Optional[datetime.datetime]]:
     """Determines a range of times for which you can kick off an execution of this asset to solve
     the most pressing constraint, alongside a maximum number of additional constraints.
     """
-    # check to find if this asset is currently being materialized by a run, and if so, which
-    # other assets are being materialized in that run
-    (
-        current_run_data_time,
-        currently_materializing,
-    ) = instance_queryer.get_in_progress_run_time_and_planned_materializations(asset_key)
-
     execution_window_start = None
     execution_window_end = None
     for constraint in sorted(constraints, key=lambda c: c.required_by_time):
         current_data_time = current_data_times.get(constraint.asset_key)
+        in_progress_data_time = in_progress_data_times.get(constraint.asset_key)
         expected_data_time = expected_data_times.get(constraint.asset_key)
 
         if not (
             # this constraint is irrelevant, as it is satisfied by the current data time
             (current_data_time is not None and current_data_time > constraint.required_data_time)
-            # this constraint is irrelevant, as materializing on this tick will not solve it
-            or (expected_data_time is None)
-            # this constraint is irrelevant, as materializing on this tick will not make progress
-            # towards solving it
-            or (current_data_time is not None and expected_data_time <= current_data_time)
             # this constraint is irrelevant, as a currently-executing run will satisfy it
             or (
-                constraint.asset_key in currently_materializing
-                # if the run hasn't started yet, assume it'll get data from the current time
-                and (current_run_data_time or current_time) > constraint.required_data_time
+                in_progress_data_time is not None
+                and in_progress_data_time > constraint.required_data_time
             )
+            # this constraint is irrelevant, as materializing on this tick will not make progress
+            # towards satisfying it
+            or (expected_data_time is None)
+            or (current_data_time is not None and expected_data_time <= current_data_time)
         ):
             if execution_window_start is None:
                 execution_window_start = constraint.required_data_time
@@ -628,18 +644,25 @@ def determine_asset_partitions_to_reconcile_for_freshness(
                 instance_queryer, asset_graph, relevant_upstream_keys, key
             )
 
-            if key not in target_asset_keys:
+            # should not execute if key is not targeted or previous run failed
+            if key not in target_asset_keys or instance_queryer.failed_in_latest_run(asset_key=key):
                 # cannot execute this asset, so if something consumes it, it should expect to
                 # recieve the current contents of the asset
                 execution_window_start = None
-                expected_data_times: Mapping[AssetKey, Optional[datetime.datetime]] = {}
             else:
-                # figure out the data times you'd expect for this key if you were to run it
+                # this key has constraints within the plan window, so must be updated within it
+                eventually_materialize.add(AssetKeyPartitionKey(key, None))
+
+                # calculate the data times you would expect if the latest currently-executing run
+                # were to successfully complete
+                in_progress_data_times = instance_queryer.get_in_progress_data_times_for_key(
+                    asset_graph, key, frozenset(relevant_upstream_keys), current_time
+                )
+
+                # calculate the data times you'd expect for this key if you were to run it
                 expected_data_times = get_expected_data_times_for_key(
                     asset_graph, current_time, expected_data_times_by_key, key
                 )
-                # this key has constraints within the plan window, so must be updated within it
-                eventually_materialize.add(AssetKeyPartitionKey(key, None))
 
                 # figure out a time window that you can execute this asset within to solve a maximum
                 # number of constraints
@@ -647,18 +670,27 @@ def determine_asset_partitions_to_reconcile_for_freshness(
                     execution_window_start,
                     _execution_window_end,
                 ) = get_execution_time_window_for_constraints(
-                    instance_queryer,
-                    constraints,
-                    current_time,
-                    current_data_times,
-                    expected_data_times,
-                    key,
+                    constraints=constraints,
+                    current_data_times=current_data_times,
+                    in_progress_data_times=in_progress_data_times,
+                    expected_data_times=expected_data_times,
                 )
 
-            # this key should be updated on this tick, as we are within the allowable window
-            if execution_window_start is not None and execution_window_start <= current_time:
-                to_materialize.add(AssetKeyPartitionKey(key, None))
+            # a key may already be in to_materialize by the time we get here if a required
+            # neighbor was selected to be updated
+            asset_key_partition_key = AssetKeyPartitionKey(key, None)
+            if asset_key_partition_key in to_materialize:
                 expected_data_times_by_key[key] = expected_data_times
+            elif (
+                # this key should be updated on this tick, as we are within the allowable window
+                execution_window_start is not None
+                and execution_window_start <= current_time
+            ):
+                to_materialize.add(asset_key_partition_key)
+                expected_data_times_by_key[key] = expected_data_times
+                # all required neighbors will be updated on the same tick
+                for required_key in asset_graph.get_required_multi_asset_keys(key):
+                    to_materialize.add(AssetKeyPartitionKey(required_key, None))
             else:
                 # if downstream assets consume this, they should expect data times equal to the
                 # current times for this asset, as it's not going to be updated
