@@ -13,6 +13,7 @@ from ..pipeline_definition import PipelineDefinition
 from ..repository_definition import (
     VALID_REPOSITORY_DATA_DICT_KEYS,
     CachingRepositoryData,
+    PendingRepositoryDefinition,
     RepositoryData,
     RepositoryDefinition,
 )
@@ -47,8 +48,11 @@ class _Repository:
             default_logger_defs, "default_logger_defs", key_type=str, value_type=LoggerDefinition
         )
 
-    def __call__(self, fn: Callable[[], Any]) -> RepositoryDefinition:
+    def __call__(
+        self, fn: Callable[[], Any]
+    ) -> Union[RepositoryDefinition, PendingRepositoryDefinition]:
         from dagster._core.definitions import AssetGroup, AssetsDefinition, SourceAsset
+        from dagster._core.definitions.cacheable_assets import CacheableAssetsDefinition
 
         check.callable_param(fn, "fn")
 
@@ -57,12 +61,15 @@ class _Repository:
 
         repository_definitions = fn()
 
-        repository_data: Union[CachingRepositoryData, RepositoryData]
+        repository_data: Optional[Union[CachingRepositoryData, RepositoryData]]
         if isinstance(repository_definitions, list):
-            repository_definitions = list(_flatten(repository_definitions))
-            bad_definitions = []
-            for i, definition in enumerate(repository_definitions):
-                if not (
+            bad_defns = []
+            repository_defns = []
+            defer_repository_data = False
+            for i, definition in enumerate(_flatten(repository_definitions)):
+                if isinstance(definition, CacheableAssetsDefinition):
+                    defer_repository_data = True
+                elif not (
                     isinstance(definition, PipelineDefinition)
                     or isinstance(definition, PartitionSetDefinition)
                     or isinstance(definition, ScheduleDefinition)
@@ -73,12 +80,15 @@ class _Repository:
                     or isinstance(definition, SourceAsset)
                     or isinstance(definition, UnresolvedAssetJobDefinition)
                 ):
-                    bad_definitions.append((i, type(definition)))
-            if bad_definitions:
+                    bad_defns.append((i, type(definition)))
+                else:
+                    repository_defns.append(definition)
+
+            if bad_defns:
                 bad_definitions_str = ", ".join(
                     [
                         "value of type {type_} at index {i}".format(type_=type_, i=i)
-                        for i, type_ in bad_definitions
+                        for i, type_ in bad_defns
                     ]
                 )
                 raise DagsterInvalidDefinitionError(
@@ -88,10 +98,15 @@ class _Repository:
                     "AssetsDefinition, or SourceAsset."
                     f"Got {bad_definitions_str}."
                 )
-            repository_data = CachingRepositoryData.from_list(
-                repository_definitions,
-                default_executor_def=self.default_executor_def,
-                default_logger_defs=self.default_logger_defs,
+
+            repository_data = (
+                None
+                if defer_repository_data
+                else CachingRepositoryData.from_list(
+                    repository_defns,
+                    default_executor_def=self.default_executor_def,
+                    default_logger_defs=self.default_logger_defs,
+                )
             )
 
         elif isinstance(repository_definitions, dict):
@@ -119,14 +134,23 @@ class _Repository:
                 "details and examples".format(type_=type(repository_definitions)),
             )
 
-        repository_def = RepositoryDefinition(
-            name=self.name,
-            description=self.description,
-            repository_data=repository_data,
-        )
+        if repository_data is None:
+            return PendingRepositoryDefinition(
+                self.name,
+                repository_definitions=list(_flatten(repository_definitions)),
+                description=self.description,
+                default_executor_def=self.default_executor_def,
+                default_logger_defs=self.default_logger_defs,
+            )
+        else:
+            repository_def = RepositoryDefinition(
+                name=self.name,
+                description=self.description,
+                repository_data=repository_data,
+            )
 
-        update_wrapper(repository_def, fn)
-        return repository_def
+            update_wrapper(repository_def, fn)
+            return repository_def
 
 
 @overload
@@ -152,7 +176,7 @@ def repository(
     description: Optional[str] = None,
     default_executor_def: Optional[ExecutorDefinition] = None,
     default_logger_defs: Optional[Mapping[str, LoggerDefinition]] = None,
-) -> Union[RepositoryDefinition, _Repository]:
+) -> Union[RepositoryDefinition, PendingRepositoryDefinition, _Repository]:
     """Create a repository from the decorated function.
 
     The decorated function should take no arguments and its return value should one of:
