@@ -7,11 +7,11 @@ from dagster._utils.backcompat import ExperimentalWarning
 
 from ..errors import DagsterInvariantViolationError
 from ..instance import DagsterInstance
-from ..storage.fs_io_manager import fs_io_manager
 from ..storage.io_manager import IOManagerDefinition
 from ..storage.mem_io_manager import mem_io_manager
 from .assets import AssetsDefinition
 from .assets_job import build_assets_job
+from .job_definition import default_job_io_manager_with_fs_io_manager_schema
 from .source_asset import SourceAsset
 from .utils import DEFAULT_IO_MANAGER_KEY
 
@@ -25,6 +25,7 @@ def materialize(
     instance: Optional[DagsterInstance] = None,
     resources: Optional[Mapping[str, object]] = None,
     partition_key: Optional[str] = None,
+    raise_on_error: bool = True,
 ) -> "ExecuteInProcessResult":
     """
     Executes a single-threaded, in-process run which materializes provided assets.
@@ -55,7 +56,9 @@ def materialize(
     partition_key = check.opt_str_param(partition_key, "partition_key")
     resources = check.opt_mapping_param(resources, "resources", key_type=str)
     resource_defs = wrap_resources_for_execution(resources)
-    resource_defs = merge_dicts({DEFAULT_IO_MANAGER_KEY: fs_io_manager}, resource_defs)
+    resource_defs = merge_dicts(
+        {DEFAULT_IO_MANAGER_KEY: default_job_io_manager_with_fs_io_manager_schema}, resource_defs
+    )
 
     with warnings.catch_warnings():
         warnings.filterwarnings(
@@ -67,7 +70,12 @@ def materialize(
             assets=assets_defs,
             source_assets=source_assets,
             resource_defs=resource_defs,
-        ).execute_in_process(run_config=run_config, instance=instance, partition_key=partition_key)
+        ).execute_in_process(
+            run_config=run_config,
+            instance=instance,
+            partition_key=partition_key,
+            raise_on_error=raise_on_error,
+        )
 
 
 def materialize_to_memory(
@@ -76,6 +84,7 @@ def materialize_to_memory(
     instance: Optional[DagsterInstance] = None,
     resources: Optional[Mapping[str, object]] = None,
     partition_key: Optional[str] = None,
+    raise_on_error: bool = True,
 ) -> "ExecuteInProcessResult":
     """
     Executes a single-threaded, in-process run which materializes provided assets in memory.
@@ -134,7 +143,12 @@ def materialize_to_memory(
             assets=assets_defs,
             source_assets=source_assets,
             resource_defs=resource_defs,
-        ).execute_in_process(run_config=run_config, instance=instance, partition_key=partition_key)
+        ).execute_in_process(
+            run_config=run_config,
+            instance=instance,
+            partition_key=partition_key,
+            raise_on_error=raise_on_error,
+        )
 
 
 def _get_required_io_manager_keys(
