@@ -473,7 +473,7 @@ class MetadataValue(ABC):
                     metadata={
                         "errors": MetadataValue.table(
                             records=[
-                                TableRecord(code="invalid-data-type", row=2, col="name"}]
+                                TableRecord(code="invalid-data-type", row=2, col="name"),
                             ],
                             schema=TableSchema(
                                 columns=[
@@ -1271,7 +1271,7 @@ class MetadataEntry(
                         MetadataEntry.table(
                             label="errors",
                             records=[
-                                TableRecord(code="invalid-data-type", row=2, col="name"}]
+                                TableRecord(code="invalid-data-type", row=2, col="name"),
                             ],
                             schema=TableSchema(
                                 columns=[
