@@ -1,6 +1,5 @@
 import inspect
 import json
-import warnings
 from collections import OrderedDict, defaultdict
 from typing import (
     TYPE_CHECKING,
@@ -23,8 +22,6 @@ from dagster._annotations import experimental, public
 from dagster._core.definitions.asset_selection import AssetSelection
 from dagster._core.definitions.assets import AssetsDefinition
 from dagster._core.definitions.partition import PartitionsDefinition
-from dagster._core.definitions.partition_key_range import PartitionKeyRange
-from dagster._core.definitions.time_window_partitions import TimeWindowPartitionsDefinition
 from dagster._core.errors import (
     DagsterInvalidDefinitionError,
     DagsterInvalidInvocationError,
@@ -713,39 +710,14 @@ class MultiAssetSensorEvaluationContext(SensorEvaluationContext):
             )
 
         partition_mapping = to_asset.infer_partition_mapping(from_asset_key)
-        downstream_partition_key_range = (
-            partition_mapping.get_downstream_partitions_for_partition_range(
-                PartitionKeyRange(partition_key, partition_key),
+        downstream_partition_key_subset = (
+            partition_mapping.get_downstream_partitions_for_partitions(
+                from_asset.partitions_def.empty_subset().with_partition_keys([partition_key]),
                 downstream_partitions_def=to_partitions_def,
-                upstream_partitions_def=from_asset.partitions_def,
             )
         )
 
-        partition_keys = to_partitions_def.get_partition_keys()
-        if (
-            downstream_partition_key_range.start not in partition_keys
-            or downstream_partition_key_range.end not in partition_keys
-        ):
-            error_msg = f"""Mapped partition key {partition_key} to downstream partition key range
-            [{downstream_partition_key_range.start}...{downstream_partition_key_range.end}] which
-            is not a valid range in the downstream partitions definition."""
-
-            if not isinstance(to_partitions_def, TimeWindowPartitionsDefinition):
-                raise DagsterInvalidInvocationError(error_msg)
-            else:
-                warnings.warn(error_msg)
-
-        if isinstance(to_partitions_def, TimeWindowPartitionsDefinition):
-            return to_partitions_def.get_partition_keys_in_range(downstream_partition_key_range)  # type: ignore[attr-defined]
-
-        # Not a time-window partition definition
-        downstream_partitions = partition_keys[
-            partition_keys.index(downstream_partition_key_range.start) : partition_keys.index(
-                downstream_partition_key_range.end
-            )
-            + 1
-        ]
-        return downstream_partitions
+        return list(downstream_partition_key_subset.get_partition_keys())
 
     @public
     def advance_cursor(
