@@ -1,3 +1,4 @@
+import logging
 import warnings
 from datetime import datetime
 from typing import TYPE_CHECKING, Any, Callable, NamedTuple, Optional, Sequence, Union, cast
@@ -5,7 +6,8 @@ from typing import TYPE_CHECKING, Any, Callable, NamedTuple, Optional, Sequence,
 import pendulum
 
 import dagster._check as check
-from dagster._annotations import PublicAttr
+from dagster._annotations import public
+from dagster._core.definitions.instigation_logger import InstigationLogger
 from dagster._core.errors import (
     DagsterInvalidDefinitionError,
     DagsterInvalidInvocationError,
@@ -44,7 +46,11 @@ from .sensor_definition import (
 from .unresolved_asset_job_definition import UnresolvedAssetJobDefinition
 
 if TYPE_CHECKING:
-    from dagster._core.host_representation.selector import JobSelector, RepositorySelector
+    from dagster._core.host_representation.selector import (
+        CodeLocationSelector,
+        JobSelector,
+        RepositorySelector,
+    )
 
 
 @whitelist_for_serdes
@@ -82,17 +88,7 @@ class RunStatusSensorCursor(
 register_serdes_tuple_fallbacks({"PipelineSensorCursor": RunStatusSensorCursor})
 
 
-class RunStatusSensorContext(
-    NamedTuple(
-        "_RunStatusSensorContext",
-        [
-            ("sensor_name", PublicAttr[str]),
-            ("dagster_run", PublicAttr[DagsterRun]),
-            ("dagster_event", PublicAttr[DagsterEvent]),
-            ("instance", PublicAttr[DagsterInstance]),
-        ],
-    )
-):
+class RunStatusSensorContext:
     """The ``context`` object available to a decorated function of ``run_status_sensor``.
 
     Attributes:
@@ -100,27 +96,58 @@ class RunStatusSensorContext(
         dagster_run (DagsterRun): the run of the job or pipeline.
         dagster_event (DagsterEvent): the event associated with the job or pipeline run status.
         instance (DagsterInstance): the current instance.
+        log (logging.Logger): the logger for the given sensor evaluation
     """
 
-    def __new__(cls, sensor_name, dagster_run, dagster_event, instance):
-
-        return super(RunStatusSensorContext, cls).__new__(
-            cls,
-            sensor_name=check.str_param(sensor_name, "sensor_name"),
-            dagster_run=check.inst_param(dagster_run, "dagster_run", DagsterRun),
-            dagster_event=check.inst_param(dagster_event, "dagster_event", DagsterEvent),
-            instance=check.inst_param(instance, "instance", DagsterInstance),
-        )
+    def __init__(self, sensor_name, dagster_run, dagster_event, instance, context=None):
+        self._sensor_name = check.str_param(sensor_name, "sensor_name")
+        self._dagster_run = check.inst_param(dagster_run, "dagster_run", DagsterRun)
+        self._dagster_event = check.inst_param(dagster_event, "dagster_event", DagsterEvent)
+        self._instance = check.inst_param(instance, "instance", DagsterInstance)
+        self._context = check.opt_inst_param(context, "context", SensorEvaluationContext)
+        self._logger: Optional[logging.Logger] = None
 
     def for_run_failure(self):
         """Converts RunStatusSensorContext to RunFailureSensorContext."""
         return RunFailureSensorContext(
-            sensor_name=self.sensor_name,
-            dagster_run=self.dagster_run,
-            dagster_event=self.dagster_event,
-            instance=self.instance,
+            sensor_name=self._sensor_name,
+            dagster_run=self._dagster_run,
+            dagster_event=self._dagster_event,
+            instance=self._instance,
+            context=self._context,
         )
 
+    @public  # type: ignore
+    @property
+    def sensor_name(self) -> str:
+        return self._sensor_name
+
+    @public  # type: ignore
+    @property
+    def dagster_run(self) -> DagsterRun:
+        return self._dagster_run
+
+    @public  # type: ignore
+    @property
+    def dagster_event(self) -> DagsterEvent:
+        return self._dagster_event
+
+    @public  # type: ignore
+    @property
+    def instance(self) -> DagsterInstance:
+        return self._instance
+
+    @public  # type: ignore
+    @property
+    def log(self) -> logging.Logger:
+        if self._context:
+            return self._context.log
+
+        if not self._logger:
+            self._logger = InstigationLogger()
+
+        return self._logger
+
     @property
     def pipeline_run(self) -> DagsterRun:
         warnings.warn(
@@ -149,6 +176,7 @@ def build_run_status_sensor_context(
     dagster_event: DagsterEvent,
     dagster_instance: DagsterInstance,
     dagster_run: DagsterRun,
+    context: Optional[SensorEvaluationContext] = None,
 ) -> RunStatusSensorContext:
     """
     Builds run status sensor context from provided parameters.
@@ -186,6 +214,7 @@ def build_run_status_sensor_context(
         instance=dagster_instance,
         dagster_run=dagster_run,
         dagster_event=dagster_event,
+        context=context,
     )
 
 
@@ -201,6 +230,7 @@ def run_failure_sensor(
                 UnresolvedAssetJobDefinition,
                 "RepositorySelector",
                 "JobSelector",
+                "CodeLocationSelector",
             ]
         ]
     ] = None,
@@ -212,6 +242,7 @@ def run_failure_sensor(
                 UnresolvedAssetJobDefinition,
                 "RepositorySelector",
                 "JobSelector",
+                "CodeLocationSelector",
             ]
         ]
     ] = None,
@@ -235,14 +266,14 @@ def run_failure_sensor(
         minimum_interval_seconds (Optional[int]): The minimum number of seconds that will elapse
             between sensor evaluations.
         description (Optional[str]): A human-readable description of the sensor.
-        monitored_jobs (Optional[List[Union[JobDefinition, GraphDefinition, UnresolvedAssetJobDefinition, RepositorySelector, JobSelector]]]):
+        monitored_jobs (Optional[List[Union[JobDefinition, GraphDefinition, UnresolvedAssetJobDefinition, RepositorySelector, JobSelector, CodeLocationSelector]]]):
             The jobs in the current repository that will be monitored by this failure sensor.
             Defaults to None, which means the alert will be sent when any job in the current
             repository fails.
         monitor_all_repositories (bool): If set to True, the sensor will monitor all runs in the
             Dagster instance. If set to True, an error will be raised if you also specify
             monitored_jobs or job_selection. Defaults to False.
-        job_selection (Optional[List[Union[JobDefinition, GraphDefinition, RepositorySelector, JobSelector]]]):
+        job_selection (Optional[List[Union[JobDefinition, GraphDefinition, RepositorySelector, JobSelector, CodeLocationSelector]]]):
             (deprecated in favor of monitored_jobs) The jobs in the current repository that will be
             monitored by this failure sensor. Defaults to None, which means the alert will be sent
             when any job in the repository fails.
@@ -304,7 +335,7 @@ class RunStatusSensorDefinition(SensorDefinition):
         minimum_interval_seconds (Optional[int]): The minimum number of seconds that will elapse
             between sensor evaluations.
         description (Optional[str]): A human-readable description of the sensor.
-        monitored_jobs (Optional[List[Union[JobDefinition, GraphDefinition, UnresolvedAssetJobDefinition, JobSelector, RepositorySelector]]]):
+        monitored_jobs (Optional[List[Union[JobDefinition, GraphDefinition, UnresolvedAssetJobDefinition, JobSelector, RepositorySelector, CodeLocationSelector]]]):
             The jobs in the current repository that will be monitored by this sensor. Defaults to
             None, which means the alert will be sent when any job in the repository fails.
         monitor_all_repositories (bool): If set to True, the sensor will monitor all runs in the
@@ -333,6 +364,7 @@ class RunStatusSensorDefinition(SensorDefinition):
                     UnresolvedAssetJobDefinition,
                     "RepositorySelector",
                     "JobSelector",
+                    "CodeLocationSelector",
                 ]
             ]
         ] = None,
@@ -343,7 +375,11 @@ class RunStatusSensorDefinition(SensorDefinition):
     ):
 
         from dagster._core.event_api import RunShardedEventsCursor
-        from dagster._core.host_representation.selector import JobSelector, RepositorySelector
+        from dagster._core.host_representation.selector import (
+            CodeLocationSelector,
+            JobSelector,
+            RepositorySelector,
+        )
         from dagster._core.storage.event_log.base import EventRecordsFilter
 
         check.str_param(name, "name")
@@ -360,15 +396,39 @@ class RunStatusSensorDefinition(SensorDefinition):
                 UnresolvedAssetJobDefinition,
                 RepositorySelector,
                 JobSelector,
+                CodeLocationSelector,
             ),
         )
         check.inst_param(default_status, "default_status", DefaultSensorStatus)
 
+        # coerce CodeLocationSelectors to RepositorySelectors with repo name "__repository__"
+        monitored_jobs = [
+            job.to_repository_selector() if isinstance(job, CodeLocationSelector) else job
+            for job in (monitored_jobs or [])
+        ]
+
         self._run_status_sensor_fn = check.callable_param(
             run_status_sensor_fn, "run_status_sensor_fn"
         )
         event_type = PIPELINE_RUN_STATUS_TO_EVENT_TYPE[run_status]
 
+        # split monitored_jobs into external repos, external jobs, and jobs in the current repo
+        other_repos = (
+            [x for x in monitored_jobs if isinstance(x, RepositorySelector)]
+            if monitored_jobs
+            else []
+        )
+
+        other_repo_jobs = (
+            [x for x in monitored_jobs if isinstance(x, JobSelector)] if monitored_jobs else []
+        )
+
+        current_repo_jobs = (
+            [x for x in monitored_jobs if not isinstance(x, (JobSelector, RepositorySelector))]
+            if monitored_jobs
+            else []
+        )
+
         def _wrapped_fn(context: SensorEvaluationContext):
             # initiate the cursor to (most recent event id, current timestamp) when:
             # * it's the first time starting the sensor
@@ -412,22 +472,6 @@ class RunStatusSensorDefinition(SensorDefinition):
                 limit=5,
             )
 
-            # split monitored_jobs into external repos, external jobs, and jobs in the current repo
-            other_repos = (
-                [x for x in monitored_jobs if isinstance(x, RepositorySelector)]
-                if monitored_jobs
-                else []
-            )
-            other_repo_jobs = (
-                [x for x in monitored_jobs if isinstance(x, JobSelector)] if monitored_jobs else []
-            )
-
-            current_repo_jobs = (
-                [x for x in monitored_jobs if not isinstance(x, (JobSelector, RepositorySelector))]
-                if monitored_jobs
-                else []
-            )
-
             for event_record in event_records:
                 event_log_entry = event_record.event_log_entry
                 storage_id = event_record.storage_id
@@ -523,6 +567,7 @@ class RunStatusSensorDefinition(SensorDefinition):
                                 dagster_run=pipeline_run,
                                 dagster_event=event_log_entry.dagster_event,
                                 instance=context.instance,
+                                context=context,
                             )
                         )
                         if sensor_return is not None:
@@ -628,6 +673,7 @@ def run_status_sensor(
                 UnresolvedAssetJobDefinition,
                 "RepositorySelector",
                 "JobSelector",
+                "CodeLocationSelector",
             ]
         ]
     ] = None,
@@ -639,6 +685,7 @@ def run_status_sensor(
                 UnresolvedAssetJobDefinition,
                 "RepositorySelector",
                 "JobSelector",
+                "CodeLocationSelector",
             ]
         ]
     ] = None,
@@ -663,14 +710,14 @@ def run_status_sensor(
         minimum_interval_seconds (Optional[int]): The minimum number of seconds that will elapse
             between sensor evaluations.
         description (Optional[str]): A human-readable description of the sensor.
-        monitored_jobs (Optional[List[Union[PipelineDefinition, GraphDefinition, UnresolvedAssetJobDefinition, RepositorySelector, JobSelector]]]):
+        monitored_jobs (Optional[List[Union[PipelineDefinition, GraphDefinition, UnresolvedAssetJobDefinition, RepositorySelector, JobSelector, CodeLocationSelector]]]):
             Jobs in the current repository that will be monitored by this sensor. Defaults to None, which means the alert will
             be sent when any job in the repository matches the requested run_status. Jobs in external repositories can be monitored by using
             RepositorySelector or JobSelector.
         monitor_all_repositories (bool): If set to True, the sensor will monitor all runs in the Dagster instance.
             If set to True, an error will be raised if you also specify monitored_jobs or job_selection.
             Defaults to False.
-        job_selection (Optional[List[Union[PipelineDefinition, GraphDefinition, RepositorySelector, JobSelector]]]):
+        job_selection (Optional[List[Union[PipelineDefinition, GraphDefinition, RepositorySelector, JobSelector, CodeLocationSelector]]]):
             (deprecated in favor of monitored_jobs) Jobs in the current repository that will be
             monitored by this sensor. Defaults to None, which means the alert will be sent when
             any job in the repository matches the requested run_status.
