@@ -1,4 +1,5 @@
 import copy
+import logging
 from contextlib import ExitStack
 from datetime import datetime
 from enum import Enum
@@ -21,6 +22,7 @@ from typing_extensions import TypeAlias, TypeGuard
 
 import dagster._check as check
 from dagster._annotations import public
+from dagster._core.definitions.instigation_logger import InstigationLogger
 from dagster._serdes import whitelist_for_serdes
 from dagster._utils import ensure_gen, merge_dicts
 from dagster._utils.schedules import is_valid_cron_schedule
@@ -35,7 +37,7 @@ from ..errors import (
 )
 from ..instance import DagsterInstance
 from ..instance.ref import InstanceRef
-from ..storage.pipeline_run import PipelineRun
+from ..storage.pipeline_run import DagsterRun
 from .graph_definition import GraphDefinition
 from .mode import DEFAULT_MODE_NAME
 from .pipeline_definition import PipelineDefinition
@@ -104,10 +106,23 @@ class ScheduleEvaluationContext:
 
     """
 
-    __slots__ = ["_instance_ref", "_scheduled_execution_time", "_exit_stack", "_instance"]
+    __slots__ = [
+        "_instance_ref",
+        "_scheduled_execution_time",
+        "_exit_stack",
+        "_instance",
+        "_log_key",
+        "_logger",
+        "_repository_name",
+        "_schedule_name",
+    ]
 
     def __init__(
-        self, instance_ref: Optional[InstanceRef], scheduled_execution_time: Optional[datetime]
+        self,
+        instance_ref: Optional[InstanceRef],
+        scheduled_execution_time: Optional[datetime],
+        repository_name: Optional[str] = None,
+        schedule_name: Optional[str] = None,
     ):
         self._exit_stack = ExitStack()
         self._instance = None
@@ -116,12 +131,25 @@ class ScheduleEvaluationContext:
         self._scheduled_execution_time = check.opt_inst_param(
             scheduled_execution_time, "scheduled_execution_time", datetime
         )
+        self._log_key = (
+            [
+                repository_name,
+                schedule_name,
+                scheduled_execution_time.strftime("%Y%m%d_%H%M%S"),
+            ]
+            if repository_name and schedule_name and scheduled_execution_time
+            else None
+        )
+        self._logger = None
+        self._repository_name = repository_name
+        self._schedule_name = schedule_name
 
     def __enter__(self):
         return self
 
     def __exit__(self, _exception_type, _exception_value, _traceback):
         self._exit_stack.close()
+        self._logger = None
 
     @public  # type: ignore
     @property
@@ -143,6 +171,37 @@ class ScheduleEvaluationContext:
     def scheduled_execution_time(self) -> Optional[datetime]:
         return self._scheduled_execution_time
 
+    @property
+    def log(self) -> logging.Logger:
+        if self._logger:
+            return self._logger
+
+        if not self._instance_ref:
+            self._logger = self._exit_stack.enter_context(
+                InstigationLogger(
+                    self._log_key,
+                    repository_name=self._repository_name,
+                    name=self._schedule_name,
+                )
+            )
+
+        self._logger = self._exit_stack.enter_context(
+            InstigationLogger(
+                self._log_key,
+                self.instance,
+                repository_name=self._repository_name,
+                name=self._schedule_name,
+            )
+        )
+        return cast(InstigationLogger, self._logger)
+
+    def has_captured_logs(self):
+        return self._logger and self._logger.has_captured_logs()
+
+    @property
+    def log_key(self) -> Optional[List[str]]:
+        return self._log_key
+
 
 class DecoratedScheduleFunction(NamedTuple):
     """Wrapper around the decorated schedule function.  Keeps track of both to better support the
@@ -192,9 +251,34 @@ def build_schedule_context(
 
 
 @whitelist_for_serdes
-class ScheduleExecutionData(NamedTuple):
-    run_requests: Optional[Sequence[RunRequest]]
-    skip_message: Optional[str]
+class ScheduleExecutionData(
+    NamedTuple(
+        "_ScheduleExecutionData",
+        [
+            ("run_requests", Optional[Sequence[RunRequest]]),
+            ("skip_message", Optional[str]),
+            ("captured_log_key", Optional[Sequence[str]]),
+        ],
+    )
+):
+    def __new__(
+        cls,
+        run_requests: Optional[Sequence[RunRequest]] = None,
+        skip_message: Optional[str] = None,
+        captured_log_key: Optional[Sequence[str]] = None,
+    ):
+        check.opt_sequence_param(run_requests, "run_requests", RunRequest)
+        check.opt_str_param(skip_message, "skip_message")
+        check.opt_list_param(captured_log_key, "captured_log_key", str)
+        check.invariant(
+            not (run_requests and skip_message), "Found both skip data and run request data"
+        )
+        return super(ScheduleExecutionData, cls).__new__(
+            cls,
+            run_requests=run_requests,
+            skip_message=skip_message,
+            captured_log_key=captured_log_key,
+        )
 
 
 class ScheduleDefinition:
@@ -535,14 +619,16 @@ class ScheduleDefinition:
             RunRequest(
                 run_key=request.run_key,
                 run_config=request.run_config,
-                tags=merge_dicts(request.tags, PipelineRun.tags_for_schedule(self)),
+                tags=merge_dicts(request.tags, DagsterRun.tags_for_schedule(self)),
                 asset_selection=request.asset_selection,
             )
             for request in run_requests
         ]
 
         return ScheduleExecutionData(
-            run_requests=run_requests_with_schedule_tags, skip_message=skip_message
+            run_requests=run_requests_with_schedule_tags,
+            skip_message=skip_message,
+            captured_log_key=context.log_key if context.has_captured_logs() else None,
         )
 
     def has_loadable_target(self):
