@@ -506,6 +506,10 @@ class DagsterEvent(
             check.opt_str_param(step_key, "step_key"),
         )
 
+    @property
+    def node_handle(self) -> Optional[NodeHandle]:
+        return self.solid_handle
+
     @property
     def solid_name(self) -> str:
         check.invariant(self.solid_handle is not None)
