@@ -1,7 +1,7 @@
 import base64
 from abc import ABC, abstractmethod
 from enum import Enum
-from typing import Callable, Iterable, List, Mapping, NamedTuple, Optional, Sequence, Set, Union
+from typing import Callable, Iterable, Mapping, NamedTuple, Optional, Sequence, Set, Union
 
 import dagster._check as check
 from dagster._core.assets import AssetDetails
@@ -20,7 +20,7 @@ from dagster._seven import json
 
 
 class EventLogConnection(NamedTuple):
-    records: List[EventLogRecord]
+    records: Sequence[EventLogRecord]
     cursor: str
     has_more: bool
 
@@ -294,9 +294,24 @@ class EventLogStorage(ABC, MayHaveInstanceWeakref):
     ) -> Mapping[AssetKey, Optional[EventLogEntry]]:
         pass
 
+    def supports_add_asset_event_tags(self) -> bool:
+        return False
+
+    def add_asset_event_tags(
+        self,
+        event_id: int,
+        event_timestamp: float,
+        asset_key: AssetKey,
+        new_tags: Mapping[str, str],
+    ) -> None:
+        raise NotImplementedError()
+
     @abstractmethod
     def get_event_tags_for_asset(
-        self, asset_key: AssetKey, filter_tags: Optional[Mapping[str, str]] = None
+        self,
+        asset_key: AssetKey,
+        filter_tags: Optional[Mapping[str, str]] = None,
+        filter_event_id: Optional[int] = None,
     ) -> Sequence[Mapping[str, str]]:
         pass
 
