@@ -4,7 +4,13 @@ from dagster import _check as check
 from dagster._serdes import ConfigurableClass, ConfigurableClassData
 
 from .base_storage import DagsterStorage
-from .event_log.base import AssetRecord, EventLogRecord, EventLogStorage, EventRecordsFilter
+from .event_log.base import (
+    AssetRecord,
+    EventLogConnection,
+    EventLogRecord,
+    EventLogStorage,
+    EventRecordsFilter,
+)
 from .runs.base import RunStorage
 from .schedules.base import ScheduleStorage
 
@@ -15,6 +21,7 @@ if TYPE_CHECKING:
     from dagster._core.events.log import EventLogEntry
     from dagster._core.execution.backfill import BulkActionStatus, PartitionBackfill
     from dagster._core.execution.stats import RunStepKeyStatsSnapshot
+    from dagster._core.host_representation.origin import ExternalPipelineOrigin
     from dagster._core.scheduler.instigation import (
         InstigatorState,
         InstigatorTick,
@@ -27,6 +34,7 @@ if TYPE_CHECKING:
         DagsterRun,
         JobBucket,
         PipelineRunStatsSnapshot,
+        RunPartitionData,
         RunRecord,
         RunsFilter,
         TagBucket,
@@ -127,6 +135,14 @@ class LegacyRunStorage(RunStorage, ConfigurableClass):
     def inst_data(self):
         return self._inst_data
 
+    @property
+    def _instance(self):
+        return self._storage._instance  # pylint: disable=protected-access
+
+    def register_instance(self, instance):
+        if not self._storage._instance:  # pylint: disable=protected-access
+            self._storage.register_instance(instance)
+
     @classmethod
     def config_type(cls):
         return {
@@ -242,7 +258,7 @@ class LegacyRunStorage(RunStorage, ConfigurableClass):
 
     @property
     def supports_bucket_queries(self):
-        return self._storage.run_storage.supports_bucket_queries()
+        return self._storage.run_storage.supports_bucket_queries
 
     def migrate(self, print_fn: Optional[Callable] = None, force_rebuild_all: bool = False):
         return self._storage.run_storage.migrate(print_fn, force_rebuild_all)
@@ -282,6 +298,18 @@ class LegacyRunStorage(RunStorage, ConfigurableClass):
     def update_backfill(self, partition_backfill: "PartitionBackfill"):
         return self._storage.run_storage.update_backfill(partition_backfill)
 
+    def get_run_partition_data(self, runs_filter: "RunsFilter") -> Sequence["RunPartitionData"]:
+        return self._storage.run_storage.get_run_partition_data(runs_filter)
+
+    def kvs_get(self, keys: Set[str]) -> Mapping[str, str]:
+        return self._storage.run_storage.kvs_get(keys)
+
+    def kvs_set(self, pairs: Mapping[str, str]) -> None:
+        return self._storage.run_storage.kvs_set(pairs)
+
+    def replace_job_origin(self, run: "DagsterRun", job_origin: "ExternalPipelineOrigin"):
+        return self._storage.run_storage.replace_job_origin(run, job_origin)
+
 
 class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
     def __init__(self, storage, inst_data=None):
@@ -310,6 +338,14 @@ class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
         ).rehydrate()
         return LegacyEventLogStorage(storage, inst_data=inst_data)
 
+    @property
+    def _instance(self):
+        return self._storage._instance  # pylint: disable=protected-access
+
+    def register_instance(self, instance):
+        if not self._storage._instance:  # pylint: disable=protected-access
+            self._storage.register_instance(instance)
+
     def get_logs_for_run(
         self,
         run_id: str,
@@ -317,49 +353,49 @@ class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
         of_type: Optional[Union["DagsterEventType", Set["DagsterEventType"]]] = None,
         limit: Optional[int] = None,
     ) -> Iterable["EventLogEntry"]:
-        return self._storage.event_storage.get_logs_for_run(run_id, cursor, of_type, limit)
+        return self._storage.event_log_storage.get_logs_for_run(run_id, cursor, of_type, limit)
 
     def get_stats_for_run(self, run_id: str) -> "PipelineRunStatsSnapshot":
-        return self._storage.event_storage.get_stats_for_run(run_id)
+        return self._storage.event_log_storage.get_stats_for_run(run_id)
 
     def get_step_stats_for_run(
         self, run_id: str, step_keys=None
     ) -> Sequence["RunStepKeyStatsSnapshot"]:
-        return self._storage.event_storage.get_step_stats_for_run(run_id, step_keys)
+        return self._storage.event_log_storage.get_step_stats_for_run(run_id, step_keys)
 
     def store_event(self, event: "EventLogEntry"):
-        return self._storage.event_storage.store_event(event)
+        return self._storage.event_log_storage.store_event(event)
 
     def delete_events(self, run_id: str):
-        return self._storage.event_storage.delete_events(run_id)
+        return self._storage.event_log_storage.delete_events(run_id)
 
     def upgrade(self):
-        return self._storage.event_storage.upgrade()
+        return self._storage.event_log_storage.upgrade()
 
     def reindex_events(self, print_fn: Optional[Callable] = None, force: bool = False):
-        return self._storage.event_storage.reindex_events(print_fn, force)
+        return self._storage.event_log_storage.reindex_events(print_fn, force)
 
     def reindex_assets(self, print_fn: Optional[Callable] = None, force: bool = False):
-        return self._storage.event_storage.reindex_assets(print_fn, force)
+        return self._storage.event_log_storage.reindex_assets(print_fn, force)
 
     def wipe(self):
-        return self._storage.event_storage.wipe()
+        return self._storage.event_log_storage.wipe()
 
     def watch(self, run_id: str, cursor: str, callback: Callable):
-        return self._storage.event_storage.watch(run_id, cursor, callback)
+        return self._storage.event_log_storage.watch(run_id, cursor, callback)
 
     def end_watch(self, run_id: str, handler: Callable):
-        return self._storage.event_storage.end_watch(run_id, handler)
+        return self._storage.event_log_storage.end_watch(run_id, handler)
 
     @property
     def is_persistent(self) -> bool:
-        return self._storage.event_storage.is_persistent
+        return self._storage.event_log_storage.is_persistent
 
     def dispose(self):
-        return self._storage.event_storage.dispose()
+        return self._storage.event_log_storage.dispose()
 
     def optimize_for_dagit(self, statement_timeout: int, pool_recycle: int):
-        return self._storage.event_storage.optimize_for_dagit(statement_timeout, pool_recycle)
+        return self._storage.event_log_storage.optimize_for_dagit(statement_timeout, pool_recycle)
 
     def get_event_records(
         self,
@@ -367,18 +403,20 @@ class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
         limit: Optional[int] = None,
         ascending: bool = False,
     ) -> Iterable[EventLogRecord]:
-        return self._storage.event_storage.get_event_records(event_records_filter, limit, ascending)
+        return self._storage.event_log_storage.get_event_records(
+            event_records_filter, limit, ascending
+        )
 
     def get_asset_records(
         self, asset_keys: Optional[Sequence["AssetKey"]] = None
     ) -> Iterable[AssetRecord]:
-        return self._storage.event_storage.get_asset_records(asset_keys)
+        return self._storage.event_log_storage.get_asset_records(asset_keys)
 
     def has_asset_key(self, asset_key: "AssetKey") -> bool:
-        return self._storage.event_storage.has_asset_key(asset_key)
+        return self._storage.event_log_storage.has_asset_key(asset_key)
 
     def all_asset_keys(self) -> Iterable["AssetKey"]:
-        return self._storage.event_storage.all_asset_keys()
+        return self._storage.event_log_storage.all_asset_keys()
 
     def get_asset_keys(
         self,
@@ -386,12 +424,12 @@ class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
         limit: Optional[int] = None,
         cursor: Optional[str] = None,
     ) -> Iterable["AssetKey"]:
-        return self._storage.event_storage.get_asset_keys(prefix, limit, cursor)
+        return self._storage.event_log_storage.get_asset_keys(prefix, limit, cursor)
 
     def get_latest_materialization_events(
         self, asset_keys: Sequence["AssetKey"]
     ) -> Mapping["AssetKey", Optional["EventLogEntry"]]:
-        return self._storage.event_storage.get_latest_materialization_events(asset_keys)
+        return self._storage.event_log_storage.get_latest_materialization_events(asset_keys)
 
     def get_asset_events(
         self,
@@ -405,7 +443,7 @@ class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
         before_timestamp=None,
         cursor: Optional[int] = None,  # deprecated
     ) -> Union[Iterable["EventLogEntry"], Iterable[Tuple[int, "EventLogEntry"]]]:
-        return self._storage.event_storage.get_asset_events(
+        return self._storage.event_log_storage.get_asset_events(
             asset_key,
             partitions,
             before_cursor,
@@ -418,15 +456,34 @@ class LegacyEventLogStorage(EventLogStorage, ConfigurableClass):
         )
 
     def get_asset_run_ids(self, asset_key: "AssetKey") -> Iterable[str]:
-        return self._storage.event_storage.get_asset_run_ids(asset_key)
+        return self._storage.event_log_storage.get_asset_run_ids(asset_key)
 
     def wipe_asset(self, asset_key: "AssetKey"):
-        return self._storage.event_storage.wipe_asset(asset_key)
+        return self._storage.event_log_storage.wipe_asset(asset_key)
 
     def get_materialization_count_by_partition(
         self, asset_keys: Sequence["AssetKey"]
     ) -> Mapping["AssetKey", Mapping[str, int]]:
-        return self._storage.event_storage.get_materialization_count_by_partition(asset_keys)
+        return self._storage.event_log_storage.get_materialization_count_by_partition(asset_keys)
+
+    def get_event_tags_for_asset(
+        self,
+        asset_key: "AssetKey",
+        filter_tags: Optional[Mapping[str, str]] = None,
+        filter_event_id: Optional[int] = None,
+    ) -> Sequence[Mapping[str, str]]:
+        return self._storage.event_log_storage.get_event_tags_for_asset(
+            asset_key, filter_tags, filter_event_id
+        )
+
+    def get_records_for_run(
+        self,
+        run_id,
+        cursor=None,
+        of_type=None,
+        limit=None,
+    ) -> EventLogConnection:
+        return self._storage.event_log_storage.get_records_for_run(run_id, cursor, of_type, limit)
 
 
 class LegacyScheduleStorage(ScheduleStorage, ConfigurableClass):
@@ -456,6 +513,14 @@ class LegacyScheduleStorage(ScheduleStorage, ConfigurableClass):
         ).rehydrate()
         return LegacyScheduleStorage(storage, inst_data=inst_data)
 
+    @property
+    def _instance(self):
+        return self._storage._instance  # pylint: disable=protected-access
+
+    def register_instance(self, instance):
+        if not self._storage._instance:  # pylint: disable=protected-access
+            self._storage.register_instance(instance)
+
     def wipe(self):
         return self._storage.schedule_storage.wipe()
 
@@ -532,3 +597,6 @@ class LegacyScheduleStorage(ScheduleStorage, ConfigurableClass):
 
     def optimize_for_dagit(self, statement_timeout: int, pool_recycle: int):
         return self._storage.schedule_storage.optimize_for_dagit(statement_timeout, pool_recycle)
+
+    def dispose(self):
+        return self._storage.schedule_storage.dispose()
