@@ -12,7 +12,7 @@ from watchdog.observers.polling import PollingObserver
 from dagster import Field, Float, StringSource
 from dagster import _check as check
 from dagster._core.execution.compute_logs import mirror_stream_to_file
-from dagster._core.storage.pipeline_run import PipelineRun
+from dagster._core.storage.pipeline_run import DagsterRun
 from dagster._serdes import ConfigurableClass, ConfigurableClassData
 from dagster._seven import json
 from dagster._utils import ensure_dir, ensure_file, touch_file
@@ -226,7 +226,7 @@ class LocalComputeLogManager(CapturedLogManager, ComputeLogManager, Configurable
     ###############################################
     @contextmanager
     def _watch_logs(self, pipeline_run, step_key=None):
-        check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+        check.inst_param(pipeline_run, "pipeline_run", DagsterRun)
         check.opt_str_param(step_key, "step_key")
 
         log_key = self.build_log_key_for_run(
@@ -265,7 +265,7 @@ class LocalComputeLogManager(CapturedLogManager, ComputeLogManager, Configurable
         )
 
     def get_key(self, pipeline_run, step_key):
-        check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+        check.inst_param(pipeline_run, "pipeline_run", DagsterRun)
         check.opt_str_param(step_key, "step_key")
         return step_key or pipeline_run.pipeline_name
 
@@ -277,7 +277,7 @@ class LocalComputeLogManager(CapturedLogManager, ComputeLogManager, Configurable
         pass
 
     def on_watch_finish(self, pipeline_run, step_key=None):
-        check.inst_param(pipeline_run, "pipeline_run", PipelineRun)
+        check.inst_param(pipeline_run, "pipeline_run", DagsterRun)
         check.opt_str_param(step_key, "step_key")
         log_key = self.build_log_key_for_run(
             pipeline_run.run_id, step_key or pipeline_run.pipeline_name
