@@ -20,7 +20,10 @@ AVAILABLE_EXAMPLES = [
     "assets_pandas_pyspark",
     "assets_pandas_type_metadata",
     "assets_smoke_test",
+    "quickstart_aws",
     "quickstart_etl",
+    "quickstart_gcp",
+    "quickstart_snowflake",
     "tutorial_dbt_dagster",
     "tutorial_notebook_assets",
     "deploy_docker",
