@@ -1,20 +1,18 @@
-from dagster._core.definitions import AssetGroup, CompositeSolidDefinition
+from dagster._core.definitions import AssetGroup
 from dagster._core.definitions import DagsterRunMetadataValue as DagsterPipelineRunMetadataValue
 from dagster._core.definitions import (
     DynamicOutputDefinition,
     InputDefinition,
     Materialization,
     ModeDefinition,
+    NodeInvocation,
     OutputDefinition,
     PartitionSetDefinition,
     PipelineDefinition,
     PresetDefinition,
     ScheduleExecutionContext,
     SensorExecutionContext,
-    SolidDefinition,
-    SolidInvocation,
     build_assets_job,
-    composite_solid,
     daily_schedule,
     default_executors,
     hourly_schedule,
@@ -31,15 +29,15 @@ from dagster._core.execution.api import (
     reexecute_pipeline,
     reexecute_pipeline_iterator,
 )
-from dagster._core.execution.context.compute import SolidExecutionContext
+from dagster._core.execution.context.compute import OpExecutionContext
 from dagster._core.execution.context.invocation import build_solid_context
 from dagster._core.execution.results import (
     CompositeSolidExecutionResult,
+    OpExecutionResult,
     PipelineExecutionResult,
-    SolidExecutionResult,
 )
 from dagster._core.storage.fs_io_manager import custom_path_fs_io_manager, fs_io_manager
-from dagster._core.storage.pipeline_run import PipelineRun, PipelineRunStatus
+from dagster._core.storage.pipeline_run import DagsterRun, DagsterRunStatus
 from dagster._utils.partitions import (
     create_offset_partition_selector,
     date_partition_range,
